qr library
Classes
- QrCode
- QrImage
- Renders the encoded data from a QrCode in a portable format.
- QrPayload
- A standalone accumulator for data and encoding modes to be formatted into a QR code.
- QrValidationResult
Enums
- QrErrorCorrectLevel
- QR Code error correction level.
Extension Types
- QrEciValue
- ECI value for QR Codes.
Exceptions / Errors
- InputTooLongException
- Thrown when the provided data exceeds the capacity of a QR code.